local Skins = AleaUI:Module("Skins")
local _G = _G

local default_background_color = Skins.default_background_color
local default_border_color = Skins.default_border_color
local default_font = Skins.default_font
local default_texture = Skins.default_texture

local default_button_background = Skins.default_button_background
local default_button_border 	= Skins.default_button_border
local default_border_color_dark = Skins.default_border_color_dark

local varName = 'worldmap'
AleaUI.default_settings.skins[varName] = true

local function Skin_WorldMap()
	if not AleaUI.db.skins.enableAll then return end
	if not AleaUI.db.skins[varName] then return end

	_G['WorldMapFrame']:StripTextures()
	WorldMapFrame.BorderFrame:StripTextures()
	WorldMapFrame.BorderFrame.Inset:StripTextures()

	_G['QuestScrollFrame']:StripTextures()

	_G['WorldMapFrameNavBar']:StripTextures()
	_G['WorldMapFrameNavBarOverlay']:StripTextures()
	--Skins.ThemeBackdrop('WorldMapFrameNavBar')
	
	local sizeUpPoints = { "BOTTOMLEFT", 'WorldMapScrollFrame', 'TOPLEFT', 0 , 0 }
	local sizeDownPoints = { "BOTTOMLEFT", 'WorldMapScrollFrame', 'TOPLEFT', 0 , 0 }
	
	local defaultPoint = sizeUpPoints

	local WorldMapFrameNavBar_BG = WorldMapFrameNavBar:CreateTexture()
	WorldMapFrameNavBar_BG:SetPoint('TOPLEFT', WorldMapFrameNavBar, 'TOPLEFT', -1, -1)
	WorldMapFrameNavBar_BG:SetPoint('BOTTOMRIGHT', WorldMapScrollFrame, 'TOPRIGHT', 0, 1)
	WorldMapFrameNavBar_BG:SetColorTexture(0,0,0,1)
	
	local WorldMapFrame_BG = WorldMapScrollFrame:CreateTexture()
	WorldMapFrame_BG:SetOutside()
	WorldMapFrame_BG:SetColorTexture(0,0,0,1)

	WorldMapFrameNavBar:ClearAllPoints()
	WorldMapFrameNavBar:SetPoint(defaultPoint[1], _G[defaultPoint[2]], defaultPoint[3], defaultPoint[4], defaultPoint[5])

	hooksecurefunc(WorldMapFrameNavBar, 'SetPoint', function(self, point, parent, anchor, xpos, ypos)
		if ( point ~= defaultPoint[1] ) or 
		   ( parent ~= _G[defaultPoint[2]] ) or
		   ( anchor ~= defaultPoint[3] ) or 
		   ( xpos ~= defaultPoint[4] ) or
		   ( ypos ~= defaultPoint[5] ) then
			
			WorldMapFrameNavBar:ClearAllPoints()
			WorldMapFrameNavBar:SetPoint(defaultPoint[1], _G[defaultPoint[2]], defaultPoint[3], defaultPoint[4], defaultPoint[5])

		end
	end)

	hooksecurefunc('WorldMap_ToggleSizeUp', function()
		defaultPoint = sizeUpPoints
		WorldMapFrameNavBar:SetPoint(defaultPoint[1], _G[defaultPoint[2]], defaultPoint[3], defaultPoint[4], defaultPoint[5])
	--	print('T', 'Done', WorldMapFrame_InWindowedMode())
	end)
	hooksecurefunc('WorldMap_ToggleSizeDown', function()
		defaultPoint = sizeDownPoints
		WorldMapFrameNavBar:SetPoint(defaultPoint[1], _G[defaultPoint[2]], defaultPoint[3], defaultPoint[4], defaultPoint[5])
	--	print('T', 'Done', WorldMapFrame_InWindowedMode())
	end)
	
--	Skins.ThemeButton(QuestScrollFrame.ViewAll)

	Skins.ThemeScrollBar('QuestScrollFrameScrollBar')
	Skins.ThemeBackdrop('WorldMapFrame')	

	Skins.ThemeButton(QuestMapFrame.DetailsFrame.BackButton)

	QuestMapFrame.DetailsFrame.AbandonButton:StripTextures()
	Skins.ThemeButton(QuestMapFrame.DetailsFrame.AbandonButton)

	QuestMapFrame.DetailsFrame.ShareButton:StripTextures()
	Skins.ThemeButton(QuestMapFrame.DetailsFrame.ShareButton)

	QuestMapFrame.DetailsFrame.TrackButton:StripTextures()
	Skins.ThemeButton(QuestMapFrame.DetailsFrame.TrackButton)
		
	QuestMapFrame.VerticalSeparator:Kill()
	
	Skins.ThemeScrollBar('QuestMapDetailsScrollFrameScrollBar')
	
	local QuestScrollFrame_BG = QuestScrollFrame:CreateTexture()
	QuestScrollFrame_BG:SetDrawLayer('BACKGROUND', -1)
	QuestScrollFrame_BG:SetOutside(QuestScrollFrame.Background)
	QuestScrollFrame_BG:SetColorTexture(0,0,0,1)
	
	WorldMapFrameTutorialButton:SetShown(false)
	WorldMapFrameTutorialButton:Hide()
	WorldMapFrameTutorialButton:HookScript('OnShow', WorldMapFrameTutorialButton.Hide)
	
--	WorldMapFrameTutorialButton.Ring:Kill()
--	WorldMapFrameTutorialButtonRingPulse:Kill()
--	WorldMapFrameTutorialButton:GetHighlightTexture():Kill()

	Skins.ThemeIconButton(WorldMapFrame.UIElementsFrame.OpenQuestPanelButton, true, a1,a2,a3,a4, 0.18)
	Skins.ThemeIconButton(WorldMapFrame.UIElementsFrame.CloseQuestPanelButton, true, a1,a2,a3,a4, 0.18)

	local rewardFrames = {
		['MoneyFrame'] = true,
		['XPFrame'] = true,
	--	['SpellFrame'] = false,
		['HonorFrame'] = true,
		['SkillPointFrame'] = true, -- this may have extra textures.. need to check on it when possible
	}

	local hookedFrames = {}
		
	local function HandleReward(frame)

		if not hookedFrames[frame] and frame.Name then
			hookedFrames[frame] = true
			
			frame.NameFrame:SetAlpha(0)
			frame.Icon:SetTexCoord(unpack(AleaUI.media.texCoord))
			
			AleaUI:CreateBackdrop(frame, frame.Icon, default_border_color, { 0, 0, 0, 0 })

			local temp = CreateFrame('Frame', nil, frame)
			temp:EnableMouse(false)
			temp:SetSize(100, 40)
			temp:SetPoint('TOPLEFT', frame.Icon, 'TOPRIGHT', 3, 0)
			temp:SetPoint('BOTTOMLEFT', frame.Icon, 'BOTTOMRIGHT', 3, 0)

			frame.Name:SetFont(default_font, Skins.default_font_size)
			
			AleaUI:CreateBackdrop(frame, temp, default_border_color, { 0, 0, 0, 0.3 })

		end
		if frame.Count then
			frame.Count:ClearAllPoints()
			frame.Count:SetPoint("BOTTOMRIGHT", frame.Icon, "BOTTOMRIGHT", 2, 0)
			if(frame.CircleBackground) then
				frame.CircleBackground:SetAlpha(0)
				frame.CircleBackgroundGlow:SetAlpha(0)
			end
		end		
	end

	for frame, obj in pairs(MapQuestInfoRewardsFrame) do
		if frame and type(obj) == 'table' then
			HandleReward(obj)
		end
	end

	hooksecurefunc('QuestInfo_GetRewardButton', function(rewardsFrame, index)
		local button = MapQuestInfoRewardsFrame.RewardButtons[index]
		if(button) then
			HandleReward(button)
		end
	end)
	
end

AleaUI:OnInit2(Skin_WorldMap)